package com.zg.project.wisdom.mapper;

import java.math.BigDecimal;
import java.util.Date;
import java.util.List;
import com.zg.project.wisdom.domain.RkInfo;
import com.zg.project.wisdom.domain.vo.StockStatisticVO;
import io.lettuce.core.dynamic.annotation.Param;

/**
 * 库存单据明细Mapper接口
 * 
 * @author zg
 * @date 2026-01-20
 */
public interface RkInfoMapper 
{
    /**
     * 查询库存单据明细
     * 
     * @param id 库存单据明细主键
     * @return 库存单据明细
     */
    public RkInfo selectRkInfoById(Long id);

    /**
     * 查询库存单据明细列表
     * 
     * @param rkInfo 库存单据明细
     * @return 库存单据明细集合
     */
    public List<RkInfo> selectRkInfoList(RkInfo rkInfo);

    /**
     * 新增库存单据明细
     * 
     * @param rkInfo 库存单据明细
     * @return 结果
     */
    public int insertRkInfo(RkInfo rkInfo);

    /**
     * 修改库存单据明细
     * 
     * @param rkInfo 库存单据明细
     * @return 结果
     */
    public int updateRkInfo(RkInfo rkInfo);

    /**
     * 删除库存单据明细
     * 
     * @param id 库存单据明细主键
     * @return 结果
     */
    public int deleteRkInfoById(Long id);

    /**
     * 批量删除库存单据明细
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    int deleteRkInfoByIds(@Param("ids") Long[] ids);

    /**
     * 修改库存明细执行状态
     */
    int updateExecStatusByIds(@Param("ids") List<Long> ids,
                              @Param("execStatus") String execStatus);

    /**
     * 根据单据编号查询库存明细数量
     */
    int countByBillNo(String billNo);

    /**
     * 根据入库明细ID查询非预入库数量
     */
    int countNotPreByIds(@Param("rkInfoIds") List<Long> rkInfoIds);

    /**
     * 根据入库明细ID更新实收数量
     */
    void updateRealQtyById(
            @Param("id") Long id,
            @Param("realQty") BigDecimal realQty
    );

    /**
     * 根据入库明细ID更新出库状态
     */
    void updateIsChukuById(
            @Param("id") Long id,
            @Param("isChuku") String isChuku
    );

    /**
     * 标记借料已归还
     */
    int updateBorrowReturn(@Param("id") Long id,
                           @Param("isBorrowed") String isBorrowed,
                           @Param("returnTime") Date returnTime);

    List<RkInfo> selectRkInfoByIds(@Param("rkInfoIds") List<Long> rkInfoIds);
    /**
     * 库存统计（金额 / 库位数 / 数量）
     */
    StockStatisticVO selectStockStatisticByCondition(RkInfo query);

}
